==> servicecatalog-model-6.3.0-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceBrokerFluentImpl<A extends ClusterServiceBrokerFluent<A>> extends BaseFluent<A> implements ClusterServiceBrokerFluent<A>{
  public ClusterServiceBrokerFluentImpl() {
  }
  public ClusterServiceBrokerFluentImpl(ClusterServiceBroker instance) {
    this.withApiVersion(instance.getApiVersion()); 
    this.withKind(instance.getKind()); 
    this.withMetadata(instance.getMetadata()); 
    this.withSpec(instance.getSpec()); 
    this.withStatus(instance.getStatus()); 
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterServiceBrokerSpecBuilder spec;
  private ClusterServiceBrokerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterServiceBrokerFluent.MetadataNested<A> withNewMetadata() {
    return new ClusterServiceBrokerFluentImpl.MetadataNestedImpl();
  }
  public ClusterServiceBrokerFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterServiceBrokerFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterServiceBrokerFluent.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterServiceBrokerFluent.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterServiceBrokerFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServiceBrokerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterServiceBrokerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterServiceBrokerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterServiceBrokerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterServiceBrokerFluent.SpecNested<A> withNewSpec() {
    return new ClusterServiceBrokerFluentImpl.SpecNestedImpl();
  }
  public ClusterServiceBrokerFluent.SpecNested<A> withNewSpecLike(ClusterServiceBrokerSpec item) {
    return new ClusterServiceBrokerFluentImpl.SpecNestedImpl(item);
  }
  public ClusterServiceBrokerFluent.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterServiceBrokerFluent.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServiceBrokerSpecBuilder().build());
  }
  public ClusterServiceBrokerFluent.SpecNested<A> editOrNewSpecLike(ClusterServiceBrokerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServiceBrokerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterServiceBrokerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterServiceBrokerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterServiceBrokerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ClusterServiceBrokerFluent.StatusNested<A> withNewStatus() {
    return new ClusterServiceBrokerFluentImpl.StatusNestedImpl();
  }
  public ClusterServiceBrokerFluent.StatusNested<A> withNewStatusLike(ClusterServiceBrokerStatus item) {
    return new ClusterServiceBrokerFluentImpl.StatusNestedImpl(item);
  }
  public ClusterServiceBrokerFluent.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterServiceBrokerFluent.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServiceBrokerStatusBuilder().build());
  }
  public ClusterServiceBrokerFluent.StatusNested<A> editOrNewStatusLike(ClusterServiceBrokerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    ClusterServiceBrokerFluentImpl that = (ClusterServiceBrokerFluentImpl) o;
    if (apiVersion != null ? !apiVersion.equals(that.apiVersion) :that.apiVersion != null) return false;
    if (kind != null ? !kind.equals(that.kind) :that.kind != null) return false;
    if (metadata != null ? !metadata.equals(that.metadata) :that.metadata != null) return false;
    if (spec != null ? !spec.equals(that.spec) :that.spec != null) return false;
    if (status != null ? !status.equals(that.status) :that.status != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterServiceBrokerFluent.MetadataNested<N>> implements ClusterServiceBrokerFluent.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterServiceBrokerSpecFluentImpl<ClusterServiceBrokerFluent.SpecNested<N>> implements ClusterServiceBrokerFluent.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterServiceBrokerSpec item) {
      this.builder = new ClusterServiceBrokerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterServiceBrokerSpecBuilder(this);
    }
    ClusterServiceBrokerSpecBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterServiceBrokerStatusFluentImpl<ClusterServiceBrokerFluent.StatusNested<N>> implements ClusterServiceBrokerFluent.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterServiceBrokerStatus item) {
      this.builder = new ClusterServiceBrokerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterServiceBrokerStatusBuilder(this);
    }
    ClusterServiceBrokerStatusBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}

==> servicecatalog-model-6.7.2-sources.jar: io/fabric8/servicecatalog/api/model/ClusterServiceBrokerFluentImpl.java <==
package io.fabric8.servicecatalog.api.model;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Boolean;
import io.fabric8.kubernetes.api.model.ObjectMeta;
import io.fabric8.kubernetes.api.model.ObjectMetaFluentImpl;
import io.fabric8.kubernetes.api.model.ObjectMetaBuilder;
import java.lang.Object;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class ClusterServiceBrokerFluentImpl<A extends ClusterServiceBrokerFluent<A>> extends BaseFluent<A> implements ClusterServiceBrokerFluent<A>{
  public ClusterServiceBrokerFluentImpl() {
  }
  public ClusterServiceBrokerFluentImpl(ClusterServiceBroker instance) {
    if (instance != null) {
      this.withApiVersion(instance.getApiVersion());
      this.withKind(instance.getKind());
      this.withMetadata(instance.getMetadata());
      this.withSpec(instance.getSpec());
      this.withStatus(instance.getStatus());
    }
  }
  private String apiVersion;
  private String kind;
  private ObjectMetaBuilder metadata;
  private ClusterServiceBrokerSpecBuilder spec;
  private ClusterServiceBrokerStatusBuilder status;
  public String getApiVersion() {
    return this.apiVersion;
  }
  public A withApiVersion(String apiVersion) {
    this.apiVersion=apiVersion; return (A) this;
  }
  public Boolean hasApiVersion() {
    return this.apiVersion != null;
  }
  public String getKind() {
    return this.kind;
  }
  public A withKind(String kind) {
    this.kind=kind; return (A) this;
  }
  public Boolean hasKind() {
    return this.kind != null;
  }
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public ObjectMeta buildMetadata() {
    return this.metadata!=null ?this.metadata.build():null;
  }
  public A withMetadata(ObjectMeta metadata) {
    _visitables.get("metadata").remove(this.metadata);
    if (metadata!=null){ this.metadata= new ObjectMetaBuilder(metadata); _visitables.get("metadata").add(this.metadata);} else { this.metadata = null; _visitables.get("metadata").remove(this.metadata); } return (A) this;
  }
  public Boolean hasMetadata() {
    return this.metadata != null;
  }
  public ClusterServiceBrokerFluentImpl.MetadataNested<A> withNewMetadata() {
    return new ClusterServiceBrokerFluentImpl.MetadataNestedImpl();
  }
  public ClusterServiceBrokerFluentImpl.MetadataNested<A> withNewMetadataLike(ObjectMeta item) {
    return new ClusterServiceBrokerFluentImpl.MetadataNestedImpl(item);
  }
  public ClusterServiceBrokerFluentImpl.MetadataNested<A> editMetadata() {
    return withNewMetadataLike(getMetadata());
  }
  public ClusterServiceBrokerFluentImpl.MetadataNested<A> editOrNewMetadata() {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): new ObjectMetaBuilder().build());
  }
  public ClusterServiceBrokerFluentImpl.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item) {
    return withNewMetadataLike(getMetadata() != null ? getMetadata(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildSpec instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServiceBrokerSpec getSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public ClusterServiceBrokerSpec buildSpec() {
    return this.spec!=null ?this.spec.build():null;
  }
  public A withSpec(ClusterServiceBrokerSpec spec) {
    _visitables.get("spec").remove(this.spec);
    if (spec!=null){ this.spec= new ClusterServiceBrokerSpecBuilder(spec); _visitables.get("spec").add(this.spec);} else { this.spec = null; _visitables.get("spec").remove(this.spec); } return (A) this;
  }
  public Boolean hasSpec() {
    return this.spec != null;
  }
  public ClusterServiceBrokerFluentImpl.SpecNested<A> withNewSpec() {
    return new ClusterServiceBrokerFluentImpl.SpecNestedImpl();
  }
  public ClusterServiceBrokerFluentImpl.SpecNested<A> withNewSpecLike(ClusterServiceBrokerSpec item) {
    return new ClusterServiceBrokerFluentImpl.SpecNestedImpl(item);
  }
  public ClusterServiceBrokerFluentImpl.SpecNested<A> editSpec() {
    return withNewSpecLike(getSpec());
  }
  public ClusterServiceBrokerFluentImpl.SpecNested<A> editOrNewSpec() {
    return withNewSpecLike(getSpec() != null ? getSpec(): new ClusterServiceBrokerSpecBuilder().build());
  }
  public ClusterServiceBrokerFluentImpl.SpecNested<A> editOrNewSpecLike(ClusterServiceBrokerSpec item) {
    return withNewSpecLike(getSpec() != null ? getSpec(): item);
  }
  
  /**
   * This method has been deprecated, please use method buildStatus instead.
   * @return The buildable object.
   */
  @Deprecated
  public ClusterServiceBrokerStatus getStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public ClusterServiceBrokerStatus buildStatus() {
    return this.status!=null ?this.status.build():null;
  }
  public A withStatus(ClusterServiceBrokerStatus status) {
    _visitables.get("status").remove(this.status);
    if (status!=null){ this.status= new ClusterServiceBrokerStatusBuilder(status); _visitables.get("status").add(this.status);} else { this.status = null; _visitables.get("status").remove(this.status); } return (A) this;
  }
  public Boolean hasStatus() {
    return this.status != null;
  }
  public ClusterServiceBrokerFluentImpl.StatusNested<A> withNewStatus() {
    return new ClusterServiceBrokerFluentImpl.StatusNestedImpl();
  }
  public ClusterServiceBrokerFluentImpl.StatusNested<A> withNewStatusLike(ClusterServiceBrokerStatus item) {
    return new ClusterServiceBrokerFluentImpl.StatusNestedImpl(item);
  }
  public ClusterServiceBrokerFluentImpl.StatusNested<A> editStatus() {
    return withNewStatusLike(getStatus());
  }
  public ClusterServiceBrokerFluentImpl.StatusNested<A> editOrNewStatus() {
    return withNewStatusLike(getStatus() != null ? getStatus(): new ClusterServiceBrokerStatusBuilder().build());
  }
  public ClusterServiceBrokerFluentImpl.StatusNested<A> editOrNewStatusLike(ClusterServiceBrokerStatus item) {
    return withNewStatusLike(getStatus() != null ? getStatus(): item);
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    ClusterServiceBrokerFluentImpl that = (ClusterServiceBrokerFluentImpl) o;
    if (!java.util.Objects.equals(apiVersion, that.apiVersion)) return false;

    if (!java.util.Objects.equals(kind, that.kind)) return false;

    if (!java.util.Objects.equals(metadata, that.metadata)) return false;

    if (!java.util.Objects.equals(spec, that.spec)) return false;

    if (!java.util.Objects.equals(status, that.status)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(apiVersion,  kind,  metadata,  spec,  status,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (apiVersion != null) { sb.append("apiVersion:"); sb.append(apiVersion + ","); }
    if (kind != null) { sb.append("kind:"); sb.append(kind + ","); }
    if (metadata != null) { sb.append("metadata:"); sb.append(metadata + ","); }
    if (spec != null) { sb.append("spec:"); sb.append(spec + ","); }
    if (status != null) { sb.append("status:"); sb.append(status); }
    sb.append("}");
    return sb.toString();
  }
  class MetadataNestedImpl<N> extends ObjectMetaFluentImpl<ClusterServiceBrokerFluentImpl.MetadataNested<N>> implements ClusterServiceBrokerFluentImpl.MetadataNested<N>,Nested<N>{
    MetadataNestedImpl(ObjectMeta item) {
      this.builder = new ObjectMetaBuilder(this, item);
    }
    MetadataNestedImpl() {
      this.builder = new ObjectMetaBuilder(this);
    }
    ObjectMetaBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withMetadata(builder.build());
    }
    public N endMetadata() {
      return and();
    }
    
  }
  class SpecNestedImpl<N> extends ClusterServiceBrokerSpecFluentImpl<ClusterServiceBrokerFluentImpl.SpecNested<N>> implements ClusterServiceBrokerFluentImpl.SpecNested<N>,Nested<N>{
    SpecNestedImpl(ClusterServiceBrokerSpec item) {
      this.builder = new ClusterServiceBrokerSpecBuilder(this, item);
    }
    SpecNestedImpl() {
      this.builder = new ClusterServiceBrokerSpecBuilder(this);
    }
    ClusterServiceBrokerSpecBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withSpec(builder.build());
    }
    public N endSpec() {
      return and();
    }
    
  }
  class StatusNestedImpl<N> extends ClusterServiceBrokerStatusFluentImpl<ClusterServiceBrokerFluentImpl.StatusNested<N>> implements ClusterServiceBrokerFluentImpl.StatusNested<N>,Nested<N>{
    StatusNestedImpl(ClusterServiceBrokerStatus item) {
      this.builder = new ClusterServiceBrokerStatusBuilder(this, item);
    }
    StatusNestedImpl() {
      this.builder = new ClusterServiceBrokerStatusBuilder(this);
    }
    ClusterServiceBrokerStatusBuilder builder;
    public N and() {
      return (N) ClusterServiceBrokerFluentImpl.this.withStatus(builder.build());
    }
    public N endStatus() {
      return and();
    }
    
  }
  
}
